searchData={"items":[{"type":"module","title":"Sitemapper","doc":"Sitemapper is an Elixir library for generating [XML Sitemaps](https://www.sitemaps.org).\n\nIt's designed to generate large sitemaps while maintaining a low\nmemory profile. It can persist sitemaps to Amazon S3, disk or any\nother adapter you wish to write.","ref":"Sitemapper.html"},{"type":"function","title":"Sitemapper.generate/2","doc":"Receives a `Stream` of `Sitemapper.URL` and returns a `Stream` of\n`{filename, body}` tuples, representing the individual sitemap XML\nfiles, followed by an index XML file.","ref":"Sitemapper.html#generate/2"},{"type":"function","title":"Configuration: - Sitemapper.generate/2","doc":"Accepts the following `Keyword` options in `opts`:\n\n* `:sitemap_url` (required) - The base URL where the generated sitemap\n  files will live. e.g. `http://example.org`, if your sitemap lives at\n  `http://example.org/sitemap.xml`\n* `:gzip` (default: `true`) - Sets whether the files are gzipped\n* `:name` - An optional suffix for the sitemap filename. e.g. If you\n  set to `news`, will produce `sitemap-news.xml.gz` and\n  `sitemap-news-00001.xml.gz` filenames.\n* `:index_lastmod` (default: `Date.utc_today()`) - An optional Date/DateTime/NaiveDateTime for the lastmod\n  element in the index.","ref":"Sitemapper.html#generate/2-configuration"},{"type":"function","title":"Sitemapper.persist/2","doc":"Receives a `Stream` of `{filename, body}` tuples, and persists\nthose to the `Sitemapper.Store`.\n\nWill raise if persistence fails.","ref":"Sitemapper.html#persist/2"},{"type":"function","title":"Configuration: - Sitemapper.persist/2","doc":"Accepts the following `Keyword` options in `opts`:\n\n* `:store` (required) - The module of the desired `Sitemapper.Store`,\n  such as `Sitemapper.S3Store` or `Sitemapper.FileStore`.\n\n* `:store_config` (optional, but usually required) -  A `Keyword` list with options for the\n  `Sitemapper.Store`.","ref":"Sitemapper.html#persist/2-configuration"},{"type":"module","title":"Sitemapper.FileStore","doc":"Store which persists sitemap on local filesystem","ref":"Sitemapper.FileStore.html"},{"type":"module","title":"Configuration - Sitemapper.FileStore","doc":"* `:path` (required) - directory to save to","ref":"Sitemapper.FileStore.html#module-configuration"},{"type":"function","title":"Sitemapper.FileStore.write/3","doc":"","ref":"Sitemapper.FileStore.html#write/3"},{"type":"module","title":"Sitemapper.S3Store","doc":"S3 sitemap store implementation using ExAWS","ref":"Sitemapper.S3Store.html"},{"type":"module","title":"Configuration - Sitemapper.S3Store","doc":"- `:bucket` (required) -- a bucket handle to save to\n- `:path` -- a prefix path which is appended to the filename\n- `:extra_props` -- a list of extra object properties","ref":"Sitemapper.S3Store.html#module-configuration"},{"type":"function","title":"Sitemapper.S3Store.write/3","doc":"","ref":"Sitemapper.S3Store.html#write/3"},{"type":"behaviour","title":"Sitemapper.Store","doc":"Store behaviour","ref":"Sitemapper.Store.html"},{"type":"callback","title":"Sitemapper.Store.write/3","doc":"Stores file with a part of sitemap into storage","ref":"Sitemapper.Store.html#c:write/3"},{"type":"module","title":"Sitemapper.URL","doc":"Represents a URL for inclusion in a Sitemap.","ref":"Sitemapper.URL.html"},{"type":"type","title":"Sitemapper.URL.changefreq/0","doc":"","ref":"Sitemapper.URL.html#t:changefreq/0"},{"type":"type","title":"Sitemapper.URL.t/0","doc":"URL structure for sitemap generation","ref":"Sitemapper.URL.html#t:t/0"},{"type":"extras","title":"Sitemapper","doc":"# Sitemapper\n\n[![Hex pm](http://img.shields.io/hexpm/v/sitemapper.svg?style=flat)](https://hex.pm/packages/sitemapper)\n\nSitemapper is an Elixir library for generating [XML Sitemaps](https://www.sitemaps.org).\n\nIt's designed to generate large sitemaps while maintaining a low memory profile. It can persist sitemaps to Amazon S3, disk or any other adapter you wish to write.","ref":"readme.html"},{"type":"extras","title":"Installation - Sitemapper","doc":"```elixir\ndef deps do\n  [\n    {:sitemapper, \"~> 0.8\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Sitemapper","doc":"```elixir\n  def generate_sitemap() do\n    config = [\n      store: Sitemapper.S3Store,\n      store_config: [bucket: \"example-bucket\"],\n      sitemap_url: \"http://example-bucket.s3-aws-region.amazonaws.com\"\n    ]\n\n    Stream.concat([1..100_001])\n    |> Stream.map(fn i ->\n      %Sitemapper.URL{\n        loc: \"http://example.com/page-#{i}\",\n        changefreq: :daily,\n        lastmod: Date.utc_today()\n      }\n    end)\n    |> Sitemapper.generate(config)\n    |> Sitemapper.persist(config)\n    |> Stream.run()\n  end\n```\n\n`Sitemapper.generate` receives a `Stream` of URLs. This makes it easy to stream the contents of an Ecto Repo into a sitemap.\n\n```elixir\n  def generate_sitemap() do\n    config = [\n      store: Sitemapper.S3Store,\n      store_config: [bucket: \"example-bucket\"],\n      sitemap_url: \"http://example-bucket.s3-aws-region.amazonaws.com\"\n    ]\n\n    Repo.transaction(fn ->\n      User\n      |> Repo.stream()\n      |> Stream.map(fn %User{username: username, updated_at: updated_at} ->\n        %Sitemapper.URL{\n          loc: \"http://example.com/users/#{username}\",\n          changefreq: :hourly,\n          lastmod: updated_at\n        }\n      end)\n      |> Sitemapper.generate(config)\n      |> Sitemapper.persist(config)\n      |> Stream.run()\n    end)\n  end\n```\n\nTo persist your sitemaps to the local file system, instead of Amazon S3, your config should look like:\n\n```elixir\n[\n  store: Sitemapper.FileStore,\n  store_config: [\n    path: sitemap_folder_path\n  ]\n]\n```\n\nNote that you'll need to finish on `Stream.run/1` or `Enum.to_list/1` to execute the stream and return the result.","ref":"readme.html#usage"},{"type":"extras","title":"Todo - Sitemapper","doc":"- Support extended Sitemap properties, like images, video, etc.","ref":"readme.html#todo"},{"type":"extras","title":"Benchmarks - Sitemapper","doc":"`sitemapper` is about 50% faster than `fast_sitemap`. In the large scenario below (1,000,000 URLs) `sitemapper` uses ~50MB peak memory consumption, while `fast_sitemap` uses ~1000MB.\n\n```shell\n$ MIX_ENV=bench mix run bench/bench.exs\nOperating System: macOS\nCPU Information: Intel(R) Core(TM) i7-4870HQ CPU @ 2.50GHz\nNumber of Available Cores: 8\nAvailable memory: 16 GB\nElixir 1.9.1\nErlang 22.0.4\n\nBenchmark suite executing with the following configuration:\nwarmup: 2 s\ntime: 10 s\nmemory time: 0 ns\nparallel: 1\ninputs: large, medium, small\nEstimated total run time: 1.20 min\n\nBenchmarking fast_sitemap - simple with input large...\nBenchmarking fast_sitemap - simple with input medium...\nBenchmarking fast_sitemap - simple with input small...\nBenchmarking sitemapper - simple with input large...\nBenchmarking sitemapper - simple with input medium...\nBenchmarking sitemapper - simple with input small...\n\n###","ref":"readme.html#benchmarks"},{"type":"extras","title":"With input large ##### - Sitemapper","doc":"Name                            ips        average  deviation         median         99th %\nsitemapper - simple          0.0353        28.32 s     ±0.00%        28.32 s        28.32 s\nfast_sitemap - simple        0.0223        44.76 s     ±0.00%        44.76 s        44.76 s\n\nComparison:\nsitemapper - simple          0.0353\nfast_sitemap - simple        0.0223 - 1.58x slower +16.45 s\n\n###","ref":"readme.html#with-input-large"},{"type":"extras","title":"With input medium ##### - Sitemapper","doc":"Name                            ips        average  deviation         median         99th %\nsitemapper - simple            0.35         2.85 s     ±0.57%         2.85 s         2.87 s\nfast_sitemap - simple          0.23         4.28 s     ±0.46%         4.28 s         4.30 s\n\nComparison:\nsitemapper - simple            0.35\nfast_sitemap - simple          0.23 - 1.50x slower +1.43 s\n\n###","ref":"readme.html#with-input-medium"},{"type":"extras","title":"With input small ##### - Sitemapper","doc":"Name                            ips        average  deviation         median         99th %\nsitemapper - simple           32.00       31.25 ms     ±8.01%       31.20 ms       37.22 ms\nfast_sitemap - simple         21.55       46.41 ms     ±6.96%       46.26 ms       56.36 ms\n\nComparison:\nsitemapper - simple           32.00\nfast_sitemap - simple         21.55 - 1.49x slower +15.16 ms\n```","ref":"readme.html#with-input-small"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n#","ref":"changelog.html"},{"type":"extras","title":"0.8.0 - Changelog","doc":"- Remove support for `Sitemapper.ping` as neither Google nor Bing support pinging sitemaps any more.\n\n#","ref":"changelog.html#0-8-0"},{"type":"extras","title":"0.7.0 - Changelog","doc":"- Always return files as binaries - previously, when gzip was disabled, file\n  content was in the form of IO data, which `Sitemapper.S3Store` would choke on.\n  If you have your own implementation of `Sitemapper.Store`, this may be a\n  breaking change for you.","ref":"changelog.html#0-7-0"}],"content_type":"text/markdown"}